pilot.filemanagement.gs_adaptor

Package pilot :: Package filemanagement :: Module gs_adaptor |

# Module gs_adaptor

source code

Google Storage based File Transfer Implementation

Classes
| GSFileAdaptor BigData File Management for Pilot Data

Variables
| OAUTH2_CLIENT_ID = ``'``1004462711324-55akehip32m59u6omdfrt9s8u8eh``...``
| OAUTH2_CLIENT_SECRET = ``'``EIMML1W7anu0XijVghws0DY-``'``
| GS_PROJECT_ID = ``'``1004462711324``'``
| __package__ = ``'``pilot.filemanagement``'``

Variables Details

  ### OAUTH2_CLIENT_ID Value:
      '1004462711324-55akehip32m59u6omdfrt9s8u8ehb0hm.apps.googleusercontent
      .com'